Index: issm/trunk-jpl/src/c/objects/Bamg/QuadTree.h
===================================================================
--- issm/trunk-jpl/src/c/objects/Bamg/QuadTree.h	(revision 12213)
+++ issm/trunk-jpl/src/c/objects/Bamg/QuadTree.h	(revision 12216)
@@ -7,6 +7,6 @@
 namespace bamg {
 
-	const int  MaxDeep  = 30;
-	const long MaxISize = ( 1L << MaxDeep);  // = 2^30 : 010000000000..000 (bitwise operation)
+	const int  MaxDepth = 30;
+	const long MaxISize = ( 1L << MaxDepth);  // = 2^30 : 010000000000..000 (bitwise operation)
 
 	class BamgVertex;
Index: issm/trunk-jpl/src/c/objects/Kriging/Quadtree.cpp
===================================================================
--- issm/trunk-jpl/src/c/objects/Kriging/Quadtree.cpp	(revision 12213)
+++ issm/trunk-jpl/src/c/objects/Kriging/Quadtree.cpp	(revision 12216)
@@ -83,18 +83,19 @@
 	Quadtree::Quadtree(){
 
-		/*Number of boxes and vertices*/
-		NbQuadtreeBox=0;
-		NbObs=0;
+		/*Initialize fields*/
+		this->MaxDepth=30;
+		this->NbQuadtreeBox=0;
+		this->NbObs=0;
 
 		/*Create container*/
-		boxcontainer=new DataSet();
+		this->boxcontainer=new DataSet();
 
 		/*Create Root, pointer toward the main box*/
-		root=NewQuadtreeBox();
+		this->root=NewQuadtreeBox();
 
 		}
 	/*}}}1*/
 	/*FUNCTION Quadtree::~Quadtree(){{{1*/
-	Quadtree::~Quadtree() {
+	Quadtree::~Quadtree(){
 
 		delete boxcontainer;
@@ -109,5 +110,4 @@
 
 	/*Intermediaries*/
-	const int     MaxDeep  = 30;
 	int          xi,yi,ij,level;
 	QuadtreeBox **pb = NULL;
@@ -121,5 +121,5 @@
 
 	/*Initialize level*/
-	level=(1L<<MaxDeep);// = 2^30
+	level=(1L<<this->MaxDepth);// = 2^30
 
 	/*Get inital box (the largest)*/
@@ -189,4 +189,5 @@
 
 	printf("Quadtree:\n");
+	printf("   MaxDepth      = %i\n",MaxDepth);
 	printf("   NbQuadtreeBox = %i\n",NbQuadtreeBox);
 	printf("   NbObs         = %i\n",NbObs);
@@ -218,5 +219,4 @@
 void Quadtree::QuadtreeColoring(double* A,int *xi,int *yi,int n){
 
-	const int     MaxDeep  = 30;
 	QuadtreeBox **pb = NULL;
 	QuadtreeBox  *b  = NULL;
@@ -226,5 +226,5 @@
 
 		/*Initialize level*/
-		level=(1L<<MaxDeep);// = 2^30
+		level=(1L<<this->MaxDepth);// = 2^30
 
 		/*Get inital box (the largest)*/
Index: issm/trunk-jpl/src/c/objects/Kriging/Quadtree.h
===================================================================
--- issm/trunk-jpl/src/c/objects/Kriging/Quadtree.h	(revision 12213)
+++ issm/trunk-jpl/src/c/objects/Kriging/Quadtree.h	(revision 12216)
@@ -35,7 +35,8 @@
 
 	public:
-		QuadtreeBox* root;          // main box
+		int          MaxDepth;      // maximum number of subdivision
+		QuadtreeBox *root;          // main box
 		long         NbQuadtreeBox; // total number of boxes
-		long         NbObs;      // number of points
+		long         NbObs;         // number of points
 
 		Quadtree();

Index: issm/trunk-jpl/src/c/objects/Bamg/QuadTree.cpp
===================================================================
--- issm/trunk-jpl/src/c/objects/Bamg/QuadTree.cpp	(revision 12213)
+++ issm/trunk-jpl/src/c/objects/Bamg/QuadTree.cpp	(revision 12216)
@@ -179,5 +179,5 @@
 		}
 
 		/*check that l is not 0 (this should not happen as MaxDeep = 30)*/
 		_assert_(level>0);
 
@@ -236,8 +236,8 @@
 
 		/*Intermediaries*/
-		QuadTreeBox *pb[MaxDeep];
-		int          pi[MaxDeep];
-		Icoor1       ii[MaxDeep];
-		Icoor1       jj[MaxDeep];
+		QuadTreeBox *pb[MaxDepth];
+		int          pi[MaxDepth];
+		Icoor1       ii[MaxDepth];
+		Icoor1       jj[MaxDepth];
 		int          level;
 		long         n0;
@@ -394,7 +394,7 @@
 		/*Original code from Frederic Hecht <hecht@ann.jussieu.fr> (BAMG v1.01, QuadTree.cpp/NearestVertexWithNormal)*/
 
-		QuadTreeBox * pb[ MaxDeep ];
-		int  pi[ MaxDeep  ];
-		Icoor1 ii[  MaxDeep ], jj [ MaxDeep];
+		QuadTreeBox * pb[ MaxDepth ];
+		int  pi[ MaxDepth  ];
+		Icoor1 ii[  MaxDepth ], jj [ MaxDepth];
 		int l; // level
 		QuadTreeBox * b;
@@ -530,7 +530,7 @@
 		const Metric  Mx(v.m);
 
-		QuadTreeBox * pb[ MaxDeep ];
-		int  pi[ MaxDeep  ];
-		Icoor1 ii[  MaxDeep ], jj [ MaxDeep];
+		QuadTreeBox * pb[ MaxDepth ];
+		int  pi[ MaxDepth  ];
+		Icoor1 ii[  MaxDepth ], jj [ MaxDepth];
 		register int l=0; // level
 		register QuadTreeBox * b;
@@ -179,5 +179,5 @@
 		}
 
-		/*check that l is not 0 (this should not happen as MaxDeep = 30)*/
+		/*check that l is not 0 (this should not happen as MaxDepth = 30)*/
 		_assert_(level>0);
 